package com.cultural.heritage.exception;

import com.cultural.heritage.common.BaseResponse;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.common.ResultUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.jdbc.CannotGetJdbcConnectionException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import java.sql.SQLException;

/**
 * 全局异常处理器
 */
@Slf4j
@RestControllerAdvice
public class GlobalExceptionHandler {

    @ExceptionHandler(BusinessException.class)
    public BaseResponse<?> businessExceptionHandler(BusinessException e) {
        log.error("BusinessException", e);
        return ResultUtils.error(e.getCode(), e.getMessage());
    }

    // 处理SQL异常（SQLException）
    @ExceptionHandler(SQLException.class)
    public BaseResponse<?> sqlExceptionHandler(SQLException e) {
        log.error("SQL error", e);
        return ResultUtils.error(ErrorCode.DATABASE_ERROR, "数据库操作失败，请检查SQL语句");
    }


    // 处理数据库连接异常（CannotGetJdbcConnectionException）
    @ExceptionHandler(CannotGetJdbcConnectionException.class)
    public BaseResponse<?> jdbcConnectionExceptionHandler(CannotGetJdbcConnectionException e) {
        log.error("Database connection error", e);
        return ResultUtils.error(ErrorCode.DATABASE_ERROR, "无法连接到数据库，请检查数据库连接配置");
    }


    @ExceptionHandler(RuntimeException.class)
    public BaseResponse<?> runtimeExceptionHandler(RuntimeException e) {
        log.error("RuntimeException", e);
        return ResultUtils.error(ErrorCode.SYSTEM_ERROR, "系统错误");
    }

}
