package com.cultural.heritage.service.book.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.exception.ThrowUtils;
import com.cultural.heritage.mapper.PhotoCategoryMapper;
import com.cultural.heritage.model.entity.PhotoCategory;
import com.cultural.heritage.service.book.PhotoCategoryService;
import com.cultural.heritage.service.book.PhotoProductsService;
import jakarta.annotation.Resource;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

@Service
public class PhotoCategoryServiceImpl extends ServiceImpl<PhotoCategoryMapper, PhotoCategory> implements PhotoCategoryService {


    @Resource
    private PhotoProductsService photoProductsService;


    /**
     * 校验
     */
    @Override
    public void validPhotoCategory(PhotoCategory photoCategory, boolean update) {

        Long id = photoCategory.getId();
        String name = photoCategory.getName();

        if (update) {
            if (id == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数id错误");
            }
        }
        if (StringUtils.isBlank(name)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "类别参数错误");
        }
        QueryWrapper<PhotoCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("name", name);
        if (update) {
            queryWrapper.ne("id", id);
            Long count = this.baseMapper.selectCount(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.OPERATION_ERROR, "当前写真类名已存在");
        } else {
            Long count = this.baseMapper.selectCount(queryWrapper);
            ThrowUtils.throwIf(count > 0, ErrorCode.OPERATION_ERROR, "不能重复添加写真类名");
        }
    }




}
