package com.cultural.heritage.service.book.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.cultural.heritage.common.ErrorCode;
import com.cultural.heritage.constant.CommonConstant;
import com.cultural.heritage.exception.BusinessException;
import com.cultural.heritage.mapper.PhotoProductsMapper;
import com.cultural.heritage.model.dto.photoProducts.PhotoProductsQueryRequest;
import com.cultural.heritage.model.entity.PhotoProducts;
import com.cultural.heritage.service.book.PhotoProductsService;
import com.cultural.heritage.utils.SqlUtils;
import org.apache.commons.lang3.ObjectUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

@Service
public class PhotoProductsServiceImpl extends ServiceImpl<PhotoProductsMapper, PhotoProducts> implements PhotoProductsService {


    /**
     * 校验
     */
    @Override
    public void validPhotoProducts(PhotoProducts photoProducts, boolean update) {
        Long id = photoProducts.getId();
        String name = photoProducts.getName();
        String introImg = photoProducts.getIntroImg();
        String richText = photoProducts.getRichText();
        Integer minNumber = photoProducts.getMinNumber();
        Integer maxNumber = photoProducts.getMaxNumber();
        String shotScene = photoProducts.getShotScene();
        BigDecimal price = photoProducts.getPrice();
        String categoryName = photoProducts.getCategoryName();

        if (update) {
            if (id == null) {
                throw new BusinessException(ErrorCode.PARAMS_ERROR, "id参错误");
            }
        }
        if (StringUtils.isAnyBlank(name, introImg, richText, shotScene, categoryName)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "参数不全");
        }
        if (ObjectUtils.anyNull(minNumber, maxNumber)) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "预约人数参数错误");
        }
        if (minNumber > maxNumber) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "最小预约人数大于最大预约人数");
        }
        if (ObjectUtils.isEmpty(price) || price.compareTo(BigDecimal.ZERO) < 0) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "价格参数错误");
        }
    }


    /**
     * 获取查询条件
     */
    @Override
    public QueryWrapper<PhotoProducts> getQueryWrapper(PhotoProductsQueryRequest photoProductsQueryRequest) {
        Long id = photoProductsQueryRequest.getId();
        String name = photoProductsQueryRequest.getName();
        String categoryName = photoProductsQueryRequest.getCategoryName();
        String sortField = photoProductsQueryRequest.getSortField();
        String sortOrder = photoProductsQueryRequest.getSortOrder();

        QueryWrapper<PhotoProducts> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq(id != null, "id", id);
        queryWrapper.like(StringUtils.isNotBlank(name), "name", name);
        queryWrapper.eq(StringUtils.isNotBlank(categoryName), "categoryName", categoryName);
        queryWrapper.orderBy(SqlUtils.validSortField(sortField), sortOrder.equals(CommonConstant.SORT_ORDER_ASC),
                sortField);
        return queryWrapper;
    }
}
